<?php

namespace App\Http\Controllers;

use App\Models\Asiento;
use App\Models\Registro;
use Illuminate\Http\Request;

class AsientoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //


    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
        $data = Registro::orderBy('id_registro', 'desc')->first()->nombre;

        return view('createAsiento', compact('data'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validar la solicitud
        $request->validate([
            'fecha.*' => 'nullable|date',
            'tipo.*' => 'nullable|integer',
            'cuenta.*' => 'nullable|string|max:200',
            'debe.*' => 'nullable|numeric',
            'haber.*' => 'nullable|numeric',
            'descripcion.*' => 'nullable|string',
        ]);

        $idRegistro = Registro::max('id_registro');


        // Preparar los registros de asientos
        $asientos = [];
        for ($i = 0; $i < count($request->fecha); $i++) {
            $asientos[] = [
                'id_registro' => $idRegistro,
                'fecha' => $request->fecha[$i] ?? null,  // Permitir null si no hay fecha
                'tipo' => $request->tipo[$i],
                'cuenta' => $request->cuenta[$i],
                'debe' => $request->debe[$i],
                'haber' => $request->haber[$i],
                'descripcion' => $request->descripcion[$i] ?? '-',  // Manejar descripción vacía
            ];
        }


        // Insertar los asientos en la tabla asientos
        \App\Models\Asiento::insert($asientos);

        return redirect()->route('registros.index');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
        $data = Asiento::where('id_registro', $id)
            ->orderBy('id') // Cambia 'fecha' al campo por el que quieras ordenar
            ->get();
        $dota = Registro::findOrFail($id);



        return view('viewProyecto', compact('data', 'dota'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
        $dota = Registro::findOrFail($id);

        $data = Asiento::where('id_registro', $id)->get();


        return view('editAsiento', compact('data', 'dota'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request)
    {

        $request->validate([
            'asiento_id.*' => 'nullable|integer|exists:asientos,id',
            'fecha.*' => 'nullable|date',
            'tipo.*' => 'nullable|integer',
            'cuenta.*' => 'nullable|string|max:200',
            'debe.*' => 'nullable|numeric',
            'haber.*' => 'nullable|numeric',
            'descripcion.*' => 'nullable|string',
            'eliminar.*' => 'nullable|boolean',
        ]);

        foreach ($request->cuenta as $index => $cuenta) {
            $asientoId = $request->asiento_id[$index] ?? null;

            if ($request->eliminar[$index] == 1 && $asientoId) {
                Asiento::findOrFail($asientoId)->delete();
                continue;
            }

            if (!$asientoId) {
                $asiento = new Asiento();
                $asiento->id_registro = $request->id_registro;
            } else {

                $asiento = Asiento::findOrFail($asientoId);
            }

            $asiento->fecha = $request->fecha[$index] ?? null;
            $asiento->tipo = $request->tipo[$index];
            $asiento->cuenta = $request->cuenta[$index];
            $asiento->debe = $request->debe[$index] ?? 0;
            $asiento->haber = $request->haber[$index] ?? 0;
            $asiento->descripcion = $request->descripcion[$index] ?? '-';

            $asiento->save();
        }

        return redirect()->route('registros.index')->with('success', 'Asientos actualizados correctamente.');
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
