<?php

namespace App\Http\Controllers;

use App\Models\Asiento;
use App\Models\Registro;
use Illuminate\Http\Request;

class BalansaController extends Controller
{
    public function showBalansa($id_registro) // Asegúrate de pasar el id_registro como parámetro
    {
        // Obtén los asientos filtrados por id_registro
        $asientos = Asiento::where('id_registro', $id_registro)->get();

        // Inicializa un array para almacenar la mayorización
        $mayorization = [];

        // Realiza la mayorización
        foreach ($asientos as $asiento) {
            // Si la cuenta no está en el array de mayorización, inicialízala
            if (!isset($mayorization[$asiento->cuenta])) {
                $mayorization[$asiento->cuenta] = [
                    'cuenta' => $asiento->cuenta,
                    'tipo' => $asiento->tipo,
                    'debe' => 0,
                    'haber' => 0,
                ];
            }

            // Suma el debe y el haber
            $mayorization[$asiento->cuenta]['debe'] += $asiento->debe ?? 0;
            $mayorization[$asiento->cuenta]['haber'] += $asiento->haber ?? 0;
        }

        // Convierte el array de mayorización a un formato adecuado
        $mayorization = array_values($mayorization);

        // Inicializa un array para la balanza final
        $balanzaFinal = [];
        $totalDebe = 0;  // Inicializa el total del debe
        $totalHaber = 0; // Inicializa el total del haber

        // Define los tipos de cuentas directamente en el controlador
        $tiposCuentas = [
            // Activos
            'banco' => 'Activo',
            'efectivo' => 'Activo',
            'Bancos' => 'Activo',
            'Efectivo' => 'Activo',
            'inversiones a corto plazo' => 'Activo',
            'inversiones a largo plazo' => 'Activo',
            'cuentas por cobrar' => 'Activo',
            'deudores diversos' => 'Activo',
            'Cuentas por cobrar' => 'Activo',
            'inventario' => 'Activo',
            'maquinaria' => 'Activo',
            'Mobiliario y equipo' => 'Activo',
            'muebles y enseres' => 'Activo',
            'edificios' => 'Activo',
            'vehículos' => 'Activo',
            'gastos pagados por anticipado' => 'Activo',
            'depósitos en garantía' => 'Activo',
            'cuentas por cobrar a largo plazo' => 'Activo',
            'activos intangibles' => 'Activo',
            'software' => 'Activo',
            'patentes' => 'Activo',
            'marcas registradas' => 'Activo',
            'terrenos' => 'Activo',
            'cargos diferidos' => 'Activo',
            'Mercancias' => 'Activo',


            // Pasivos
            'pago' => 'Pasivo',
            'compra' => 'Pasivo',
            'Cuentas por pagar' => 'Pasivo',
            'préstamos bancarios' => 'Pasivo',
            'préstamos por pagar' => 'Pasivo',
            'gastos acumulados' => 'Pasivo',
            'impuestos por pagar' => 'Pasivo',
            'intereses por pagar' => 'Pasivo',
            'obligaciones financieras' => 'Pasivo',
            'deudas a corto plazo' => 'Pasivo',
            'deudas a largo plazo' => 'Pasivo',
            'provisión para impuestos' => 'Pasivo',
            'proveedores' => 'Pasivo',
            'gastos a pagar' => 'Pasivo',

            // Capital
            'capital social' => 'Capital',
            'Capital' => 'Capital',
            'reserva legal' => 'Capital',
            'reserva de capital' => 'Capital',
            'utilidades retenidas' => 'Capital',
            'capital aportado' => 'Capital',
            'capital en acciones preferentes' => 'Capital',

            // Ingresos
            'Ventas' => 'Ingreso',
            'ingresos por servicios' => 'Ingreso',
            'ingresos por alquileres' => 'Ingreso',
            'ingresos por intereses' => 'Ingreso',
            'ingresos extraordinarios' => 'Ingreso',
            'ingresos por comisiones' => 'Ingreso',
            'ingresos por regalías' => 'Ingreso',
            'ventas de activos' => 'Ingreso',

            // Gastos
            'Gastos de Ventas' => 'Gasto',
            'gastos administrativos' => 'Gasto',
            'gastos de marketing' => 'Gasto',
            'gastos de mantenimiento' => 'Gasto',
            'gastos de investigación y desarrollo' => 'Gasto',
            'gastos financieros' => 'Gasto',
            'gastos de alquiler' => 'Gasto',
            'gastos de salarios' => 'Gasto',
            'gastos de servicios públicos' => 'Gasto',
            'gastos de seguros' => 'Gasto',
            'depreciación' => 'Gasto',
            'amortización' => 'Gasto',
            'gastos por viajes' => 'Gasto',
            'gastos de formación' => 'Gasto',
            'gastos por publicidad' => 'Gasto',
            'gastos de suministros' => 'Gasto',
            'pérdidas en inversiones' => 'Gasto',
            'Alquiler de edificios' => 'Gasto',
            'Servicios públicos' => 'Gasto',
            'Planilla' => 'Gasto',
            'Gastos Adm' => 'Gasto',
            'Flete' => 'Gasto',

            'Fletes' => 'Gasto',

            // Agrega más tipos de cuentas aquí si es necesario
        ];

        foreach ($mayorization as $item) {
            // Obtener el tipo de cuenta de la lista definida
            $tipo = $tiposCuentas[$item['cuenta']] ?? 'Desconocido';

            // Calcula la diferencia
            $diferencia = $item['debe'] - $item['haber'];

            if ($diferencia > 0) {
                // Si el debe es mayor, guarda el valor en debe
                $balanzaFinal[] = [
                    'cuenta' => $item['cuenta'],
                    'tipo' => $tipo,
                    'debe' => $diferencia,
                    'haber' => 0,
                ];
                $totalDebe += $diferencia;  // Suma al total del debe
            } elseif ($diferencia < 0) {
                // Si el haber es mayor, guarda el valor en haber
                $balanzaFinal[] = [
                    'cuenta' => $item['cuenta'],
                    'tipo' => $tipo,
                    'debe' => 0,
                    'haber' => abs($diferencia),
                ];
                $totalHaber += abs($diferencia);  // Suma al total del haber
            } else {
                // Si son iguales, guarda ambos como cero
                $balanzaFinal[] = [
                    'cuenta' => $item['cuenta'],
                    'tipo' => $tipo,
                    'debe' => 0,
                    'haber' => 0,
                ];
            }
        }

        // Retorna la vista con los datos de la balanza final y los totales
        return view('balansa.balansa', compact('balanzaFinal', 'totalDebe', 'totalHaber'));
    }
}
