<?php

namespace App\Http\Controllers;

use App\Models\Asiento;
use App\Models\Registro;
use Illuminate\Http\Request;

class ControllerBalanceGeneral extends Controller
{
    public function showBalanceGeneral($id)
    {
        // Obtener el registro seleccionado
        $registro = Registro::findOrFail($id);

        // Obtener todos los asientos relacionados con el registro
        $asientosAgrupados = Asiento::where('id_registro', $id)
            ->get()
            ->groupBy('cuenta');

        // Inicializar arrays para cada categoría
        $activos = [];
        $pasivos = [];
        $patrimonio = [];

        // Inicializar variables para calcular ingresos y gastos
        $totalIngresosDebe = 0;
        $totalIngresosHaber = 0;
        $totalGastosDebe = 0;
        $totalGastosHaber = 0;

        // Iterar por cada grupo de asientos
        foreach ($asientosAgrupados as $cuenta => $asientos) {
            $totalDebe = $asientos->sum('debe');
            $totalHaber = $asientos->sum('haber');

            // Obtener el tipo de cuenta de los asientos
            $tipoCuenta = $asientos->first()->tipo;  // Asegúrate de que el campo 'tipo' esté en la tabla Asientos

            // Calcular el resultado neto de cada cuenta
            $resultadoNeto = abs($totalDebe - $totalHaber);

            // Clasificar la cuenta según el tipo seleccionado por el usuario
            switch ($tipoCuenta) {
                case 0: // Activo
                    if ($totalDebe > $totalHaber) {
                        $activos[] = [
                            'cuenta' => $cuenta,
                            'debe' => $totalDebe - $totalHaber,
                            'haber' => 0,
                        ];
                    } else {
                        $activos[] = [
                            'cuenta' => $cuenta,
                            'debe' => 0,
                            'haber' => $totalHaber - $totalDebe,
                        ];
                    }
                    break;

                case 1: // Pasivo
                    if ($totalHaber > $totalDebe) {
                        $pasivos[] = [
                            'cuenta' => $cuenta,
                            'debe' => 0,
                            'haber' => $totalHaber - $totalDebe,
                        ];
                    } else {
                        $pasivos[] = [
                            'cuenta' => $cuenta,
                            'debe' => $totalDebe - $totalHaber,
                            'haber' => 0,
                        ];
                    }
                    break;

                case 2: // Patrimonio
                    if ($totalHaber > $totalDebe) {
                        $patrimonio[] = [
                            'cuenta' => $cuenta,
                            'debe' => 0,
                            'haber' => $totalHaber - $totalDebe,
                        ];
                    } else {
                        $patrimonio[] = [
                            'cuenta' => $cuenta,
                            'debe' => $totalDebe - $totalHaber,
                            'haber' => 0,
                        ];
                    }
                    break;

                case 3: // Ingreso
                    $totalIngresosDebe += $totalDebe;
                    $totalIngresosHaber += $totalHaber;
                    break;

                case 4: // Gasto
                    $totalGastosDebe += $totalDebe;
                    $totalGastosHaber += $totalHaber;
                    break;

                default:
                    // En caso de que el tipo de cuenta no esté definido
                    break;
            }
        }

        // Calcular utilidad o pérdida
        $utilidadOPerdida = 0;
        if ($totalIngresosHaber > $totalGastosDebe) {
            $utilidadOPerdida = $totalIngresosHaber - $totalGastosDebe;
            $patrimonio[] = [
                'cuenta' => 'Utilidad del ejercicio',
                'debe' => 0,
                'haber' => $utilidadOPerdida,
            ];
        } elseif ($totalGastosHaber > $totalIngresosDebe) {
            $utilidadOPerdida = $totalGastosHaber - $totalIngresosDebe;
            $patrimonio[] = [
                'cuenta' => 'Pérdida del ejercicio',
                'debe' => $utilidadOPerdida,
                'haber' => 0,
            ];
        }

        // Retornar la vista con los datos agrupados
        return view('balanceGeneral', compact('registro', 'activos', 'pasivos', 'patrimonio'));
    }
}

