<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Asientos Diarios</title>
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .container {
            max-height: calc(100vh - 200px); /* Ajusta la altura máxima según sea necesario */
            overflow-y: auto; /* Habilita el desplazamiento vertical */
        }
        .total-row {
            font-weight: bold;
        }
    </style>
    <script>
        function addRow() {
            const table = document.getElementById("asientosTable");
            const row = table.insertRow(table.rows.length - 1); // Insertar antes de la fila de totales
            row.innerHTML = `
                <td><input type="date" name="fecha[]" class="form-control" required></td>
                <td>
                    <select name="tipo[]" class="form-control" required>
                        <option value="0" selected>Activo</option>
                        <option value="1">Pasivo</option>
                        <option value="2">Patrimonio</option>
                        <option value="3">Ingreso</option>
                        <option value="4">Gasto</option>
                    </select>
                </td>
                <td><input type="text" name="cuenta[]" class="form-control" required></td>
                <td><input type="number" name="debe[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                <td><input type="number" name="haber[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                <td><input type="text" name="descripcion[]" class="form-control"></td>
                <td><button type="button" class="btn btn-danger" onclick="removeRow(this)">X</button></td>
            `;
        }

        function subdivision() {
            const table = document.getElementById("asientosTable");
            const row = table.insertRow(table.rows.length - 1); // Insertar antes de la fila de totales
            row.innerHTML = `
                <td><input type="date" name="" disabled class="form-control"></td>
                <input type="hidden" name="fecha[]" value="">
                <td>
                    <select name="tipo[]" class="form-control" required>
                        <option value="0" selected>Activo</option>
                        <option value="1">Pasivo</option>
                        <option value="2">Patrimonio</option>
                        <option value="3">Ingreso</option>
                        <option value="4">Gasto</option>
                    </select>
                </td>
                <td><input type="text" name="cuenta[]" class="form-control" required></td>
                <td><input type="number" name="debe[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                <td><input type="number" name="haber[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                <td><input type="text" name="" class="form-control" value="-" disabled></td>
                <input type="hidden" name="descripcion[]" value="-">
                <td><button type="button" class="btn btn-danger" onclick="removeRow(this)">X</button></td>
            `;
        }

        function removeRow(button) {
            const row = button.parentNode.parentNode;
            row.parentNode.removeChild(row);
            updateTotals();
        }

        function updateTotals() {
            let totalDebe = 0;
            let totalHaber = 0;

            const debeInputs = document.querySelectorAll('input[name="debe[]"]');
            const haberInputs = document.querySelectorAll('input[name="haber[]"]');

            debeInputs.forEach(input => {
                totalDebe += parseFloat(input.value) || 0;
            });

            haberInputs.forEach(input => {
                totalHaber += parseFloat(input.value) || 0;
            });

            document.getElementById('totalDebe').innerText = totalDebe.toFixed(2);
            document.getElementById('totalHaber').innerText = totalHaber.toFixed(2);
        }
    </script>
</head>
<body>
    <div class="container mt-5">
        <h1 class="mb-4">Proyecto: {{$data}}</h1>

        @if(session('success'))
            <div class="alert alert-success">{{ session('success') }}</div>
        @endif

        <form id="asientosForm" action="{{ route('asientos.store') }}" method="POST">
            @csrf
            <table id="asientosTable" class="table table-bordered">
                <thead>
                    <tr>
                        <th>Fecha</th>
                        <th>Tipo</th>
                        <th>Cuenta</th>
                        <th>Debe</th>
                        <th>Haber</th>
                        <th>Descripción</th>
                        <th>Eliminar</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td><input type="date" name="fecha[]" class="form-control" required></td>
                        <td>
                            <select name="tipo[]" class="form-control" required>
                                <option value="0" selected>Activo</option>
                                <option value="1">Pasivo</option>
                                <option value="2">Capital</option>
                                <option value="3">Ingreso</option>
                                <option value="4">Gasto</option>
                            </select>
                        </td>
                        <td><input type="text" name="cuenta[]" class="form-control" required></td>
                        <td><input type="number" name="debe[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                        <td><input type="number" name="haber[]" class="form-control" step="0.01" value="0" oninput="updateTotals()"></td>
                        <td><input type="text" name="descripcion[]" class="form-control"></td>
                        <td><button type="button" class="btn btn-danger" onclick="removeRow(this)">X</button></td>
                    </tr>
                </tbody>
                <tfoot>
                    <tr class="total-row">
                        <td colspan="3">Totales</td>
                        <td id="totalDebe">0.00</td>
                        <td id="totalHaber">0.00</td>
                        <td colspan="2"></td>
                    </tr>
                </tfoot>
            </table>
            <button type="button" class="btn btn-primary" onclick="addRow()">Agregar otro asiento</button>
            <button type="button" class="btn btn-secondary" onclick="subdivision()">Subdivision</button>
            <button type="submit" class="btn btn-success">Guardar</button>
            <a href="{{route('registros.index')}}" class="btn btn-warning">Regresar</a>
        </form>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
